package com.app.mysample;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.HashMap;
import java.util.Map;

import javax.enterprise.context.ConversationScoped;
import javax.enterprise.inject.Produces;
import javax.inject.Singleton;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

/**
 * Bean utilisé pour garder l'EntityManager factory et produire
 * le scope conversation de l'EntityManager pour l'injection.
 */
@Singleton
public class DataRepositoryProducer {

	private static EntityManagerFactory factory;

	@Produces
	public EntityManagerFactory getEntityManagerFactory() {
		if (factory == null) {
			Map addedOrOverridenProperties = new HashMap();
			URI dbUri = null;

			try {
				String databaseUrl = System.getenv("DATABASE_URL");
				System.out.println(databaseUrl);

				if (databaseUrl != null && !"".equals(databaseUrl)) {
					dbUri = new URI(databaseUrl);
				}
			} catch (URISyntaxException e) {
				dbUri = null;
			}

			if (dbUri != null) {
				// plateforme Heroku ==> on utilise la DATABASE_URL 
				String username = dbUri.getUserInfo().split(":")[0];
				String password = dbUri.getUserInfo().split(":")[1];
				String dbUrl = "jdbc:postgresql://" + dbUri.getHost() + ':'
						+ dbUri.getPort() + dbUri.getPath();
				addedOrOverridenProperties.put("hibernate.connection.url",
						dbUrl); 
				addedOrOverridenProperties.put(
						"hibernate.connection.driver_class",
						"org.postgresql.Driver");
				addedOrOverridenProperties.put("hibernate.dialect",
						"org.hibernate.dialect.PostgreSQLDialect");
				addedOrOverridenProperties.put("hibernate.connection.username",
						username);
				addedOrOverridenProperties.put("hibernate.connection.password",
						password);

			}

			factory = Persistence.createEntityManagerFactory("pu",
					addedOrOverridenProperties);
		}
		return factory;
	}

	@Produces
	@DataRepository
	@ConversationScoped
	public EntityManager produceEntityManager() {
		return getEntityManagerFactory().createEntityManager();
	}

}
